import { StatsModule } from "./StatsModule";
import { EnabledStats, StatsManagerOptions, StatsAcquisition, SavedStatsFormat } from "./types/types";
/**
 * Creates a new StatsManager instance
 */
declare abstract class StatsManager {
    scheduleCron: string;
    enabledStats: EnabledStats;
    debuggingMode: boolean;
    private _statsModules;
    /**
     * Manages the stats of your discord bot.
     * @param {StatsManagerOptions} options - The options for the stats manager.
     * @param {string} [options.scheduleCron = "0 0 * * * *"] - The interval in milliseconds default 1 hour. See https://crontab.guru/#0_*_*_*_* and https://www.npmjs.com/package/node-cron for more info .
     * @param {EnabledStats} [options.enabledStats = {}] - The enabled stats.
     */
    constructor(options: StatsManagerOptions);
    /**
     * Initializes the stats manager.
     * @private
     * @returns {void}
     */
    _init(): void;
    /**
     * Returns the enabled stats modules.
     * @type {StatsModule[]}
     */
    get statsModules(): StatsModule[];
    /**
     * Returns the targetted stats module.
     * @param {string} name - The name of the stats module.
     * @returns {StatsModule|undefined}
     */
    findModule(name: string): StatsModule;
    /**
     * Add custom module to your stats manager.
     * @param {StatsModule[]} modules - The stats module to add.
     * @returns {void}
     * @example
     * const customModule = new StatsModule("custom", { graphType: GraphType.LINE, dataType: "number" });
     * statsManager.addModule([customModule]);
     * statsManager.findModule("custom"); // => customModule
     * @throws {Error} If the module is already added.
     * @throws {Error} If the module has not a valid graph type.
     * @throws {Error} If the module has not a valid data type.
     */
    addModules(modules: StatsModule[]): void;
    /**
     * Acquires the stats.
     * @param {StatsAcquisition} returnedStatsFunction - The function that returns the stats.
     * @returns {Promise<void>}
     * @example
     * statsManager.acquireStats(async () => {
     * 	return {
     * 		ram: Math.round((process.memoryUsage().heapUsed / 1024 / 1024) * 100) / 100,
     * 		servers: client.guilds.size,
     * 		users: client.users.size,
     * }
     * });
     * @throws {Error} If the stats are not acquired.
     * @throws {Error} If the stats are not acquired in the correct format.
     */
    start(returnedStatsFunction: StatsAcquisition): Promise<void>;
    /**
     * Saves the stats.
     * @abstract
     * @param {SavedStatsFormat} stats - The stats to save.
     */
    abstract saveStats(stats: SavedStatsFormat): Promise<void>;
    /**
     * Gets the stats.
     * @abstract
     * @returns {Promise<SavedStatsFormat[]>}
     */
    abstract getStats(): Promise<SavedStatsFormat[]>;
    /**
     * Deletes the stats.
     * @abstract
     * @param {number[]} timestamps - The timestamps of the stats to delete.
     */
    abstract deleteStats(timestamps: number[]): Promise<void>;
}
export { StatsManager };
